@@ -5,7 +5,7 @@ use warnings;
 
 use Carp qw(croak);
 
-our $VERSION = '0.02';
+our $VERSION = '1.00';
 
 require XSLoader;
 XSLoader::load('RPi::SysInfo', $VERSION);
@@ -30,7 +30,8 @@ sub new {
     return bless {}, shift;
 }
 sub core_temp {
-    shift if ref $_[0] eq 'RPi::SysInfo';
+    shift if $_[0] && $_[0] =~ /RPi::/;
+
     my ($degree) = @_;
 
     $degree //= 'c';
@@ -55,33 +56,40 @@ sub core_temp {
         $temp = ($temp * 1.8) + 32;
     }
 
+    chomp $temp;
     return $temp;
 }
 sub cpu_percent {
     return _format(cpuPercent());
 }
 sub gpio_info {
-    shift if ref $_[0] eq 'RPi::SysInfo';
-
+    shift if $_[0] && $_[0] =~ /RPi::/;
+    
     my ($pins) = @_;
 
     $pins = ! defined $pins
         ? ''
         : join ",", @$pins;
 
-    return `raspi-gpio get $pins`;
+    my $info = `raspi-gpio get $pins`;
+    chomp $info;
+    return $info;
 }
 sub mem_percent {
     return _format(memPercent());
 }
 sub network_info {
-    return `ifconfig`;
+    my $netinfo = `ifconfig`;
+    chomp $netinfo;
+    return $netinfo;
 }
 sub raspi_config {
     my $config = `vcgencmd get_config int`;
     $config .= `vcgencmd get_config str`;
     my $cmd = 'cat /boot/config.txt | egrep -v "^\s*(#|^$)"';
     $config .= `$cmd`;
+
+    chomp $config;
     return $config;
 }
 sub file_system {
